@@ -5,5 +5,7 @@
 from .middleware_eum import *
 from .producter_consumer import *
 from .init_config_file import use_config_form_distributed_frame_config_module
+from multiprocessing import set_start_method
+set_start_method("fork")
 
 use_config_form_distributed_frame_config_module()
